"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskRecord = void 0;
const uuid_1 = require("uuid");
const handleError_1 = require("../utils/handleError");
const db_1 = require("../utils/db");
class TaskRecord {
    constructor(obj) {
        if (obj.taskTodo.length < 3 || obj.taskTodo.length > 255) {
            throw new handleError_1.ValidationError('Nazwa zawadania nie może być krótsza niż 3 znaki, oraz nie może przekraczać 255 znkaów ');
        }
        this.id = obj.id;
        this.taskTodo = obj.taskTodo;
        this.deadline = obj.deadline;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `tasks` VALUES(:id, :taskTodo, :deadline)", {
                id: this.id,
                taskTodo: this.taskTodo,
                deadline: this.deadline
            });
            return this.id;
        });
    }
    static listAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `tasks`"));
            return results.map(obj => new TaskRecord(obj));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `tasks` WHERE `id`=:id", {
                id,
            });
            return new TaskRecord(result[0]);
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `tasks` SET `deadline` = :deadline, `taskTodo` = :taskTodo WHERE `id` = :id", {
                taskTodo: this.taskTodo,
                id: this.id,
                deadline: this.deadline,
            });
        });
    }
    static delete(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `tasks` WHERE `id`= :id", {
                id,
            });
        });
    }
    static nextYear() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `tasks` WHERE `deadline` > '2023-01-01' AND `deadline` < '2023-12-31'"));
            return results.map(obj => new TaskRecord(obj));
        });
    }
}
exports.TaskRecord = TaskRecord;
//# sourceMappingURL=task.record.js.map